summaryrefslogtreecommitdiffstats
path: root/src/prefs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/prefs.cpp')
-rw-r--r--src/prefs.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/prefs.cpp b/src/prefs.cpp
index cf17d22..5e5ba4a 100644
--- a/src/prefs.cpp
+++ b/src/prefs.cpp
@@ -21,11 +21,11 @@
#include <tqwhatsthis.h>
/*
* Constructs a Prefs as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-Prefs::Prefs( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+Prefs::Prefs( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "Prefs" );
@@ -21,11 +21,11 @@
#include <tqwhatsthis.h>
/*
- * Constructs a Prefs as a child of 'tqparent', with the
+ * Constructs a Prefs as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/